@@ -44,12 +44,12 @@ use Hash::Util qw/
 
 #----> ** variables de classe **
 
-our $VERSION = 0.177;
+our $VERSION = 0.1771;
 
 #----> ** methodes publiques **
 
 sub refresh {
-    return shift->SUPER::_refresh('refresh');
+    return shift->SUPER::_refresh('workOnExceptionAlerts');
 }
 
 sub handle {
@@ -107,7 +107,7 @@ Ce module est dedie au module C<CTM::ReadEM>.
 
 =head1 AUTEUR
 
-Le Garff Yoann <weeble@cpan.org>
+Le Garff Yoann <pe.weeble@yahoo.fr>
 
 =head1 LICENCE
 
